﻿using System.Web.Mvc;
using System.Collections.Generic;
using Infragistics.Web.Mvc;
using Recon.Models;

namespace Recon.Controllers
{
	public class TestController : Controller
	{
		//
		// GET: /Test/
        //public GridModel LoadOnDemandModel { get; set; }

        public ActionResult List()
        {
            //pass a grid model to the view
            ViewModel viewModel = new ViewModel();
            viewModel.LoadOnDemandModel = CreateGridLoadOnDemand();

            GridModel grid = CreateGridModel();
            return View(grid);
        }

        private GridModel CreateGridLoadOnDemand()
        {
            GridModel grid = CreateGridModel();
            grid.ID = "gridLoadOnDemand";
            grid.LoadOnDemand = true;
            grid.DataSourceUrl = this.Url.Action("BindParent");
            grid.ColumnLayouts[0].DataSourceUrl = this.Url.Action("BindChild");

            return grid;
        }

		// Take grid creation outside as it will be used in all methods:
		private GridModel CreateGridModel()
		{
			GridModel grid = new GridModel();
                       
			// Set up properties and columns:
			grid.AutoGenerateColumns = false;
            grid.PrimaryKey = "CustomerID";
			grid.Columns = new List<GridColumn>();
			grid.Columns.Add(new GridColumn("Customer", "CustomerID", "string", "300px"));
			grid.Columns.Add(new GridColumn("Company Name", "CompanyName", "string", "150px"));
			grid.Columns.Add(new GridColumn("Country", "Country", "string", "150px"));
			grid.AutoGenerateLayouts = false;

			// Create child layout
			GridColumnLayoutModel layout = new GridColumnLayoutModel();
			layout.Key = "Orders";
			layout.ForeignKey = "CustomerID";
			layout.PrimaryKey = "OrderID";
			layout.AutoGenerateColumns = false;

			layout.Columns = new List<GridColumn>();
			layout.Columns.Add(new GridColumn("Order ID", "OrderID", "number", "100px"));
			layout.Columns.Add(new GridColumn("Customer", "CustomerID", "string", "100px"));
			layout.Columns.Add(new GridColumn("Order Date", "OrderDate", "date", "150px"));
			layout.Columns.Add(new GridColumn("Shipped Date", "ShippedDate", "date", "150px"));

     		//add that layout to the grid
			grid.ColumnLayouts.Add(layout);

            // Add paging to child layouts (different from the parent's)
            GridPaging layoutPaging = new GridPaging();
            layoutPaging.VisiblePageCount = 2;
            layoutPaging.PageSize = 5;
            //layoutPaging.Type = OpType.Remote;
            layout.Features.Add(layoutPaging);

            //And lastly set ID so the client widget can be normally interacted with (see the events in the view)
            grid.ID = "hierarchicalGrid";
			//most importantly turn Load On demand on and define response Urls:
            grid.LoadOnDemand = true;
			grid.DataSourceUrl = this.Url.Action("BindParent");
			grid.ColumnLayouts[0].DataSourceUrl = this.Url.Action("BindChild");

            var dataContext = new NorthwindDataContext();
            var dataSource = dataContext.Customers;
            var ds = dataSource.Take(30);
            grid.DataSource=ds;

            //Add features:
            GridSorting sorting = new GridSorting();
            sorting.Type = OpType.Remote;
            grid.Features.Add(sorting);
            GridPaging paging = new GridPaging();
            paging.PageSize = 10;
            paging.Type = OpType.Remote;
            grid.Features.Add(paging);

            // Return the finished model
			return grid;
		}

		public JsonResult BindParent()
		{
			//create a model
            GridModel grid = CreateGridModel();
           
			//set its data source
			var dataContext = new NorthwindDataContext();
			var dataSource = dataContext.Customers;
			grid.DataSource = dataSource.Take(30);
			//and use the GetData() method to return the results
			return grid.GetData();
		}

		public JsonResult BindChild(string path, string layout)
		{
			//create a model
			GridModel grid = CreateGridModel();
			//set its data source
			var dataContext = new NorthwindDataContext();
			var dataSource = dataContext.Orders;
			grid.DataSource = dataSource;
			//and use the GetData() method to return the results
			return grid.GetData(path, layout);
		}
	}

}
